# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKOptimizersv4Python



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkOnePlusOneEvolutionaryOptimizerv4Python
else:
    import _itkOnePlusOneEvolutionaryOptimizerv4Python

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkObjectToObjectOptimizerBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkPointPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkOptimizerParameterScalesEstimatorPython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkObjectToObjectMetricBasePython
import itk.itkSingleValuedCostFunctionv4Python
import itk.itkCostFunctionPython

def itkOnePlusOneEvolutionaryOptimizerv4D_New():
    return itkOnePlusOneEvolutionaryOptimizerv4D.New()

class itkOnePlusOneEvolutionaryOptimizerv4D(itk.itkObjectToObjectOptimizerBasePython.itkObjectToObjectOptimizerBaseTemplateD):
    r"""Proxy of C++ itkOnePlusOneEvolutionaryOptimizerv4D class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkOnePlusOneEvolutionaryOptimizerv4D_Pointer"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkOnePlusOneEvolutionaryOptimizerv4D_Pointer"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_Clone(self)

    def SetMaximumIteration(self, _arg):
        r"""
        SetMaximumIteration(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_SetMaximumIteration(self, _arg)

    def GetMaximumIteration(self):
        r"""GetMaximumIteration(self) -> unsigned int const &"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_GetMaximumIteration(self)

    def SetGrowthFactor(self, _arg):
        r"""
        SetGrowthFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_SetGrowthFactor(self, _arg)

    def GetGrowthFactor(self):
        r"""GetGrowthFactor(self) -> double const &"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_GetGrowthFactor(self)

    def SetShrinkFactor(self, _arg):
        r"""
        SetShrinkFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_SetShrinkFactor(self, _arg)

    def GetShrinkFactor(self):
        r"""GetShrinkFactor(self) -> double const &"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_GetShrinkFactor(self)

    def SetInitialRadius(self, _arg):
        r"""
        SetInitialRadius(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_SetInitialRadius(self, _arg)

    def GetInitialRadius(self):
        r"""GetInitialRadius(self) -> double const &"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_GetInitialRadius(self)

    def SetEpsilon(self, _arg):
        r"""
        SetEpsilon(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_SetEpsilon(self, _arg)

    def GetEpsilon(self):
        r"""GetEpsilon(self) -> double const &"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_GetEpsilon(self)

    def GetFrobeniusNorm(self):
        r"""GetFrobeniusNorm(self) -> double const &"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_GetFrobeniusNorm(self)

    def SetNormalVariateGenerator(self, generator):
        r"""
        SetNormalVariateGenerator(self, generator)

        Parameters
        ----------
        generator: itkRandomVariateGeneratorBase *

        """
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_SetNormalVariateGenerator(self, generator)

    def Initialize(self, initialRadius, grow=-1, shrink=-1):
        r"""
        Initialize(self, initialRadius, grow=-1, shrink=-1)

        Parameters
        ----------
        initialRadius: double
        grow: double
        shrink: double

        """
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_Initialize(self, initialRadius, grow, shrink)

    def GetCurrentCost(self):
        r"""GetCurrentCost(self) -> double const &"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_GetCurrentCost(self)

    def GetInitialized(self):
        r"""GetInitialized(self) -> bool const &"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_GetInitialized(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_StartOptimization(self, doOnlyInitialization)

    def StopOptimization(self):
        r"""StopOptimization(self)"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_StopOptimization(self)

    def GetCatchGetValueException(self):
        r"""GetCatchGetValueException(self) -> bool const &"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_GetCatchGetValueException(self)

    def SetCatchGetValueException(self, _arg):
        r"""
        SetCatchGetValueException(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_SetCatchGetValueException(self, _arg)

    def CatchGetValueExceptionOn(self):
        r"""CatchGetValueExceptionOn(self)"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_CatchGetValueExceptionOn(self)

    def CatchGetValueExceptionOff(self):
        r"""CatchGetValueExceptionOff(self)"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_CatchGetValueExceptionOff(self)

    def GetMetricWorstPossibleValue(self):
        r"""GetMetricWorstPossibleValue(self) -> double const &"""
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_GetMetricWorstPossibleValue(self)

    def SetMetricWorstPossibleValue(self, _arg):
        r"""
        SetMetricWorstPossibleValue(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_SetMetricWorstPossibleValue(self, _arg)
    __swig_destroy__ = _itkOnePlusOneEvolutionaryOptimizerv4Python.delete_itkOnePlusOneEvolutionaryOptimizerv4D

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkOnePlusOneEvolutionaryOptimizerv4D

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_cast(obj)

    def New(*args, **kargs):
        """New() -> itkOnePlusOneEvolutionaryOptimizerv4D

        Create a new object of the class itkOnePlusOneEvolutionaryOptimizerv4D and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkOnePlusOneEvolutionaryOptimizerv4D.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkOnePlusOneEvolutionaryOptimizerv4D.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkOnePlusOneEvolutionaryOptimizerv4D.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkOnePlusOneEvolutionaryOptimizerv4D in _itkOnePlusOneEvolutionaryOptimizerv4Python:
_itkOnePlusOneEvolutionaryOptimizerv4Python.itkOnePlusOneEvolutionaryOptimizerv4D_swigregister(itkOnePlusOneEvolutionaryOptimizerv4D)

